@@ -17,7 +17,7 @@ from django.http import JsonResponse
 from django.urls import reverse
 from django.utils import formats, timezone
 from django.utils.decorators import method_decorator
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.html import conditional_escape, format_html
 from django.views.generic import View
 from django.views.generic.base import ContextMixin, TemplateResponseMixin
@@ -62,7 +62,7 @@ class ModelField(object):
 
     @property
     def orderable(self):  # noqa D102
-        return True
+        return self.field.name
 
 
 class ModelAttr(object):
@@ -91,7 +91,8 @@ class ModelAttr(object):
 
     @property
     def orderable(self):  # noqa D102
-        return False
+        source = getattr(self.model, self.name)
+        return getattr(source, 'order_field', False)
 
 
 class DataSourceAttr(object):
@@ -132,7 +133,8 @@ class DataSourceAttr(object):
 
     @property
     def orderable(self):  # noqa D102
-        return False
+        source = getattr(self.data_source, self.name)
+        return getattr(source, 'order_field', False)
 
 
 class DataTableMixin(ContextMixin):
@@ -215,7 +217,13 @@ class DataTableMixin(ContextMixin):
         Data could comes from the model field or external `data_source`
         method call.
         """
-        opts = self.object_list.model._meta
+        if hasattr(self, 'object_list') and self.object_list:  # TODO backport simplification from viewflow 2.0?
+            opts = self.object_list.model._meta
+        elif hasattr(self, 'model') and self.model:
+            opts = self.model._meta
+        else:
+            opts = self.get_queryset().model._meta
+
         try:
             return ModelField(opts.get_field(attr_name))
         except FieldDoesNotExist:
@@ -235,7 +243,7 @@ class DataTableMixin(ContextMixin):
     def get_columns_def(self):
         """Return columns definition for the datables js config."""
         return [
-            {'data': field_name, 'orderable': self.get_data_attr(field_name).orderable}
+            {'data': field_name, 'orderable': bool(self.get_data_attr(field_name).orderable)}
             for field_name in self.get_list_display()
         ]
 
@@ -255,9 +263,9 @@ class DataTableMixin(ContextMixin):
         elif isinstance(value, six.integer_types + (decimal.Decimal, float)):
             return formats.number_format(value)
         elif isinstance(value, (list, tuple)):
-            return ', '.join(force_text(v) for v in value)
+            return ', '.join(force_str(v) for v in value)
         else:
-            return force_text(value)
+            return force_str(value)
 
     def get_table_data(self, start, length):
         """Get a page for datatable."""
@@ -284,11 +292,16 @@ class DataTableMixin(ContextMixin):
             requested_order = self.request_form.cleaned_data['ordering']
             for spec in requested_order:
                 column_num, column_dir = spec.get('column', 0), spec.get('dir', 'asc')
-
                 try:
-                    order = self.get_list_display()[int(column_num)]
-                    if column_dir == 'asc':
-                        order = '-' + order
+                    order = self.get_data_attr(
+                         self.get_list_display()[int(column_num)]
+                    ).orderable
+                    if order:
+                        if column_dir == 'desc':
+                            if order.startswith('-'):
+                                order = order[1:]
+                            else:
+                                order = '-' + order
                 except (IndexError, TypeError):
                     """ Skip """
                 else:
@@ -469,6 +482,9 @@ class ListModelView(TemplateResponseMixin, DataTableMixin, View):
                 "%(cls)s.get_queryset()." % {
                     'cls': self.__class__.__name__
                 })
+        if self.model is None:
+            self.model = queryset.model
+
         ordering = self.get_ordering()
         if ordering:
             if isinstance(ordering, six.string_types):
